import requests
import re
from bs4 import BeautifulSoup as bs

cookies = {}

headers = {
    'authority': 'r6.tracker.network',
    'accept': 'text/html,application/xhtml+xml,application/xml;q=0.9,image/avif,image/webp,image/apng,*/*;q=0.8,application/signed-exchange;v=b3;q=0.7',
    'accept-language': 'en-US,en;q=0.9',
    'user-agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/119.0.0.0 Safari/537.36',
}

def get_profile_views(platform, username):
    response = requests.get(f'https://r6.tracker.network/profile/{platform}/{username}', cookies=cookies, headers=headers)
    soup = bs(response.text, 'html.parser')
    try:
        profile_views_span = soup.find('span', class_='trn-profile-header__views trn-text--dimmed')
        text = profile_views_span.get_text()
        profile_views = re.search(r'\d[\d,]+', text)

        if profile_views:
            profile_views = profile_views.group(0).replace(',', '')
            return profile_views
        else:
            return "Profile/Element does not exist"
    except Exception:
        return "An error occurred while retrieving the profile views"


rjson = {
    "COPPER V": "https://imgur.com/5tMUlN8.png",
    "COPPER IV": "https://imgur.com/4FOsKqM.png",
    "COPPER III": "https://imgur.com/w4Zdkc4.png",
    "COPPER II": "https://imgur.com/doJaPHP.png",
    "COPPER I": "https://imgur.com/zeNn2EQ.png",
    "BRONZE V": "https://imgur.com/kOlkE7n.png",
    "BRONZE IV": "https://imgur.com/yqPsmmv.png",
    "BRONZE III": "https://imgur.com/1rG4FpF.png",
    "BRONZE II": "https://imgur.com/9nl8uJx.png",
    "BRONZE I": "https://imgur.com/ehnXLcR.png",
    "SILVER V": "https://imgur.com/NpBtpuL.png",
    "SILVER IV": "https://imgur.com/dXqDtfu.png",
    "SILVER III": "https://imgur.com/qEOIIhw.png",
    "SILVER II": "https://imgur.com/T1gj0oX.png",
    "SILVER I": "https://imgur.com/57Xg7xm.png",
    "GOLD V": "https://i.imgur.com/7pThZFx.png",
    "GOLD IV": "https://imgur.com/0nc7epN.png",
    "GOLD III": "https://imgur.com/hQzavB2.png",
    "GOLD II": "https://imgur.com/JN4MRjp.png",
    "GOLD I": "https://imgur.com/C7Wr3Ty.png",
    "PLATINUM V": "https://i.imgur.com/YvAyy0s.png",
    "PLATINUM IV": "https://i.imgur.com/FYoAbTw.png",
    "PLATINUM III": "https://imgur.com/5xKwhhB.png",
    "PLATINUM II": "https://imgur.com/YrDuNNC.png",
    "PLATINUM I": "https://imgur.com/jHKSXxD.png",
    "EMERALD V": "https://i.imgur.com/PeFVREp.png",
    "EMERALD IV": "https://i.imgur.com/1cQEwv5.png",
    "EMERALD III": "https://i.imgur.com/wGANDF6.png",
    "EMERALD II": "https://i.imgur.com/4lcrJKS.png",
    "EMERALD I": "https://i.imgur.com/iL7fj41.png",
    "DIAMOND V": "https://i.imgur.com/J4k8G8m.png",
    "DIAMOND IV": "https://i.imgur.com/NpmJe5S.png",
    "DIAMOND III": "https://imgur.com/u7bnEA1.png",
    "DIAMOND II": "https://imgur.com/jo5YKVm.png",
    "DIAMOND I": "https://imgur.com/h94nQF3.png",
    "CHAMPION": "https://imgur.com/Q5Qpcmt.png",
    "UNRANKED": "https://imgur.com/PvLQN8r.png"
}

def get_rank_image(rname):
    if rname in rjson:
        return rjson[rname]
    else:
        return rjson["UNRANKED"]


import requests
from bs4 import BeautifulSoup as bs

cookies = {}

headers = {
    'authority': 'r6.tracker.network',
    'accept': 'text/html,application/xhtml+xml,application/xml;q=0.9,image/avif,image/webp,image/apng,*/*;q=0.8,application/signed-exchange;v=b3;q=0.7',
    'accept-language': 'en-US,en;q=0.9',
    'user-agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/119.0.0.0 Safari/537.36',
}

def get_season_info(platform, username):
    response = requests.get(f'https://r6.tracker.network/profile/{platform}/{username}', cookies=cookies, headers=headers)
    soup = bs(response.text, 'html.parser')
    
    season_info = {}

    for quickseason in soup.select('.r6-quickseason'):
        label_element = quickseason.select_one('.r6-quickseason__label')
        value_element = quickseason.select_one('.r6-quickseason__value')
        matches_element = quickseason.select_one('.r6-quickseason__value.trn-text--dimmed')
        kd_elements = quickseason.select('small.r6-quickseason__value.trn-text--dimmed')

        if label_element and value_element and matches_element and len(kd_elements) >= 3:
            label = label_element.text.strip()
            value = value_element.text.strip()
            matches = matches_element.text.strip()
            kd = kd_elements[2].text.strip()

            if label and value and matches and kd:
                season_info[label] = {
                    'MMR': value,
                    'Matches': matches,
                    'KD': kd
                }

    return season_info


import requests
from lxml import html

cookies = {}

headers = {
    'authority': 'r6.tracker.network',
    'accept': 'text/html,application/xhtml+xml,application/xml;q=0.9,image/avif,image/webp,image/apng,*/*;q=0.8,application/signed-exchange;v=b3;q=0.7',
    'accept-language': 'en-US,en;q=0.9',
    'user-agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/119.0.0.0 Safari/537.36',
}

def get_ranked_stats(platform, username):
    response = requests.get(f'https://r6.tracker.network/profile/{platform}/{username}', cookies=cookies, headers=headers)

    if response.status_code != 200:
        return "Profile doesn't exist"

    page = html.fromstring(response.text)

    ranked_stats = {}

    time_played_element = page.xpath('/html/body/div[4]/div[2]/div[3]/div[1]/div[3]/div[1]/div[2]/div/div[1]/div[2]/text()')
    wins_element = page.xpath('/html/body/div[4]/div[2]/div[3]/div[1]/div[3]/div[1]/div[2]/div/div[2]/div[2]/text()')
    losses_element = page.xpath('/html/body/div[4]/div[2]/div[3]/div[1]/div[3]/div[1]/div[2]/div/div[3]/div[2]/text()')
    matches_element = page.xpath('/html/body/div[4]/div[2]/div[3]/div[1]/div[3]/div[1]/div[2]/div/div[4]/div[2]/text()')
    deaths_element = page.xpath('/html/body/div[4]/div[2]/div[3]/div[1]/div[3]/div[1]/div[2]/div/div[5]/div[2]/text()')
    kills_element = page.xpath('/html/body/div[4]/div[2]/div[3]/div[1]/div[3]/div[1]/div[2]/div/div[6]/div[2]/text()')
    wins_percent_element = page.xpath('/html/body/div[4]/div[2]/div[3]/div[1]/div[3]/div[1]/div[2]/div/div[7]/div[2]/text()')
    kd_element = page.xpath('/html/body/div[4]/div[2]/div[3]/div[1]/div[3]/div[1]/div[2]/div/div[8]/div[2]/text()')
    kills_match_element = page.xpath('/html/body/div[4]/div[2]/div[3]/div[1]/div[3]/div[1]/div[2]/div/div[9]/div[2]/text()')
    kills_min = page.xpath('/html/body/div[4]/div[2]/div[3]/div[1]/div[3]/div[1]/div[2]/div/div[10]/div[2]/text()')
    level_element = page.xpath('//div[@class="trn-defstat__name" and text()="Level"]/following-sibling::div[@class="trn-defstat__value-stylized"]')
    current_rank_element = page.xpath('/html/body/div[4]/div[2]/div[3]/div[1]/div[4]/div[2]/div[1]/div[1]/svg/g/text[2]/tspan[1]')

    if time_played_element:
        time_played_text = time_played_element[0].strip()
        ranked_stats['Time Played'] = time_played_text

    if wins_element:
        wins_text = wins_element[0].strip()
        ranked_stats['Wins'] = wins_text

    if losses_element:
        losses_text = losses_element[0].strip()
        ranked_stats['Losses'] = losses_text

    if matches_element:
        matches_text = matches_element[0].strip()
        ranked_stats['Matches Played'] = matches_text

    if deaths_element:
        deaths_text = deaths_element[0].strip()
        ranked_stats['Deaths'] = deaths_text

    if kills_element:
        kills_text = kills_element[0].strip()
        ranked_stats['Kills'] = kills_text
        
    if wins_percent_element:
        wins_percent_text = wins_percent_element[0].strip()
        ranked_stats['Win %'] = wins_percent_text
        
    if kd_element:
        kd_text = kd_element[0].strip()
        ranked_stats['K/D'] = kd_text
        
    if kills_match_element:
        kills_match_text = kills_match_element[0].strip()
        ranked_stats['Kills/Match'] = kills_match_text
        
    if kills_min:
        kills_min_text = kills_min[0].strip()
        ranked_stats['Kills/Min'] = kills_min_text

    if current_rank_element:
        current_rank_text = current_rank_element[0].text_content().strip()
        ranked_stats['Current Rank'] = current_rank_text

    if level_element:
        level_text = level_element[0].text_content().strip()
        ranked_stats['Player Level'] = level_text

    return ranked_stats


import requests
from lxml import html

cookies = {}

headers = {
    'authority': 'r6.tracker.network',
    'accept': 'text/html,application/xhtml+xml,application/xml;q=0.9,image/avif,image/webp,image/apng,*/*;q=0.8,application/signed-exchange;v=b3;q=0.7',
    'accept-language': 'en-US,en;q=0.9',
    'user-agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/119.0.0.0 Safari/537.36',
}

def get_profile_level(platform, username):
    response = requests.get(f'https://r6.tracker.network/profile/{platform}/{username}', cookies=cookies, headers=headers)

    if response.status_code != 200:
        return "Failed to retrieve the page"

    page = html.fromstring(response.text)

    level_element = page.xpath('//div[@class="trn-defstat__name" and text()="Level"]/following-sibling::div[@class="trn-defstat__value-stylized"]')

    if level_element:
        level = level_element[0].text_content().strip()
        return level
    
    return "Level not found"


from .profile_views import get_profile_views
from .level import get_profile_level
from .rank_icon import get_rank_image
from .season_info import get_season_info
from .general_stats import get_general_stats
from .ranked_stats import get_ranked_stats


from setuptools import setup

setup(
    name="r6_stats",
    version="1.0.2",
    packages=["r6_stats"],
    install_requires=["requests", "beautifulsoup4", "lxml"],
    description="Python package to retreive player stats from the game Rainbow 6: Siege",
    long_description="Python package to retreive player stats from the game Rainbow 6: Siege"
)